@@ -1,9 +1,7 @@
 package Catalyst::Authentication::Credential::Twitter;
-BEGIN {
-  $Catalyst::Authentication::Credential::Twitter::AUTHORITY = 'cpan:JESSESTAY';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT:  Twitter authentication for Catalyst
-$Catalyst::Authentication::Credential::Twitter::VERSION = '2.0.4';
+$Catalyst::Authentication::Credential::Twitter::VERSION = '2.0.5';
 use strict;
 use warnings;
 use base qw( Class::Accessor::Fast );
@@ -181,7 +179,7 @@ Catalyst::Authentication::Credential::Twitter - Twitter authentication for Catal
 
 =head1 VERSION
 
-version 2.0.4
+version 2.0.5
 
 =head1 SYNOPSIS
 
